# frozen_string_literal: true

# Remove this file from activesupport/lib/active_support/core_ext.rb when deleting the deprecation.
ActiveSupport.deprecator.warn <<~TEXT
  active_support/core_ext/benchmark.rb is deprecated and will be removed in Rails 8.2 without replacement.
TEXT
